@@ -37,10 +37,12 @@ if rdflib.__version__ >= "3.0.0" :
 	from rdflib	import Graph
 	from rdflib	import RDF  as ns_rdf
 	from rdflib	import RDFS as ns_rdfs
+	from rdflib import XSD  as ns_xsd
 else :
 	from rdflib.Graph	import Graph
-	from rdflib.RDFS	import RDFSNS as ns_rdfs
-	from rdflib.RDF		import RDFNS  as ns_rdf
+	from rdflib.RDFS	import RDFSNS  as ns_rdfs
+	from rdflib.Literal import _XSD_NS as ns_xsd
+	from rdflib.RDF		import RDFNS   as ns_rdf
 	
 ns_owl = Namespace("http://www.w3.org/2002/07/owl#")
 
@@ -574,6 +576,29 @@ class MicrodataConversion(Microdata) :
 			else :
 				return Literal( node.getAttribute("content") )
 
+		elif node.tagName == "meter" or node.tagName == "data" :
+			if node.hasAttribute("value") :
+				val  = node.getAttribute("value")
+				# check whether the attribute value can be defined as a float or an integer
+				try :
+					fval = int(val)
+					dt   = ns_xsd["integer"]
+				except :
+					# Well, not an int, try then a integer
+					try :
+						fval = float(val)
+						dt   = ns_xsd["float"]
+					except :
+						# Sigh, this is not a valid value, but let it go through as a plain literal nevertheless
+						fval = val
+						dt   = None
+				if dt :
+					return Literal( val, datatype = dt)
+				else :
+					return Literal( val )
+			else :
+				return Literal( "" )
+
 		elif node.tagName == "time" and node.hasAttribute("datetime") :
 			litval = node.getAttribute("datetime")
 			dtype  = get_time_type(litval)
@@ -590,7 +615,7 @@ class MicrodataConversion(Microdata) :
 		
 	def generate_property_values( self, subject, predicate, objects, context) :
 		"""
-		Generate the property values for for a specific subject and predicate. The context should specify whether
+		Generate the property values for a specific subject and predicate. The context should specify whether
 		the objects should be added in an RDF list or each triples individually.
 		
 		@param subject: RDF subject
