@@ -36,10 +36,9 @@ __all__ = [
 ]
 
 import logging
+logger = logging.getLogger(__name__)
 import warnings
 
-_LOGGER = logging.getLogger(__name__)
-
 import base64
 import xml.dom.minidom
 
@@ -148,7 +147,7 @@ class Identifier(Node, unicode):  # allow Identifiers to be Nodes in the Graph
         This tries to implement this:
         http://www.w3.org/TR/sparql11-query/#modOrderBy
 
-        Variables are no included in the SPARQL list, but
+        Variables are not included in the SPARQL list, but
         they are greater than BNodes and smaller than everything else
 
         """
@@ -184,16 +183,14 @@ class Identifier(Node, unicode):  # allow Identifiers to be Nodes in the Graph
         return self == other
 
     def __hash__(self):
-        return hash(type(self)) ^ hash(unicode(self))
+        t = type(self)
+        fqn = t.__module__ + '.' + t.__name__
+        return hash(fqn) ^ hash(unicode(self))
 
 
 class URIRef(Identifier):
     """
     RDF URI Reference: http://www.w3.org/TR/rdf-concepts/#section-Graph-URIref
-
-    The URIRef constructor will do a limited check for valid URIs,
-    essentially just making sure that the string includes no illegal
-    characters (``<, >, ", {, }, |, \\, `, ^``)
     """
 
     __slots__ = ()
@@ -207,7 +204,7 @@ class URIRef(Identifier):
                     value += "#"
 
         if not _is_valid_uri(value):
-            _LOGGER.warning('%s does not look like a valid URI, trying to serialize this will break.'%value)
+            logger.warning('%s does not look like a valid URI, trying to serialize this will break.'%value)
 
 
         try:
@@ -220,6 +217,15 @@ class URIRef(Identifier):
         return unicode(self)
 
     def n3(self, namespace_manager = None):
+        """
+        This will do a limited check for valid URIs,
+        essentially just making sure that the string includes no illegal
+        characters (``<, >, ", {, }, |, \\, `, ^``)
+
+        :param namespace_manager: if not None, will be used to make up
+             a prefixed name
+        """
+
         if not _is_valid_uri(self):
             raise Exception('"%s" does not look like a valid URI, I cannot serialize this as N3/Turtle. Perhaps you wanted to urlencode it?'%self)
 
@@ -926,8 +932,12 @@ class Literal(Identifier):
         -- 6.5.1 Literal Equality (RDF: Concepts and Abstract Syntax)
 
         """
-
-        return unicode.__hash__(self) ^ hash(self.language.lower() if self.language else None) ^ hash(self.datatype)
+        res = super(Literal, self).__hash__()
+        if self.language:
+            res ^= hash(self.language.lower())
+        if self.datatype:
+            res ^= hash(self.datatype)
+        return res
 
     @py3compat.format_doctest_out
     def __eq__(self, other):
@@ -1498,7 +1508,7 @@ def bind(datatype, pythontype, constructor=None, lexicalizer=None):
 
     """
     if datatype in _toPythonMapping:
-        _LOGGER.warning("datatype '%s' was already bound. Rebinding." %
+        logger.warning("datatype '%s' was already bound. Rebinding." %
                         datatype)
 
     if constructor == None:
@@ -1523,7 +1533,12 @@ class Variable(Identifier):
         return unicode.__new__(cls, value)
 
     def __repr__(self):
-        return self.n3()
+        if self.__class__ is Variable:
+            clsName = "rdflib.term.Variable"
+        else:
+            clsName = self.__class__.__name__
+
+        return """%s(%s)""" % (clsName, super(Variable, self).__repr__())
 
     def toPython(self):
         return "?%s" % self
